@@ -551,21 +551,26 @@ def update_app_utils(appname, branch, keys=False, reboot=False):
 
     # If using a shared utils repo, then need to move into this app's utils folder.
     APP_UTILS_DIR = appname + "-utils"
-    local('ls -al %s' % APP_UTILS_DIR)
-    if os.path.isdir(APP_UTILS_DIR):
-        lcd(APP_UTILS_DIR)
-        local("pwd")
-    
-    # tar it up
+
     TAR_NAME = "app-utils"
     CONFIG_DIR = "config/"
     ENV_DIR = "environments/"
     KEY_DIR = ("keys/" + ENVIRONMENT) if (keys in TRUTH_VALUES) else ""
 
     DIRS_TO_TAR = CONFIG_DIR + " " + ENV_DIR + " " + KEY_DIR
+
+    if os.path.isdir(APP_UTILS_DIR):
+        with lcd(APP_UTILS_DIR+"/"):
+            local('git archive %s --format=tar.gz --output=../%s.tar.gz %s %s %s' % (branch, TAR_NAME, CONFIG_DIR, ENV_DIR, KEY_DIR)) 
+    else:
+        local('git archive %s --format=tar.gz --output=%s.tar.gz %s %s %s' % (branch, TAR_NAME, CONFIG_DIR, ENV_DIR, KEY_DIR))
+
+    
+    # tar it up
+
     print(DIRS_TO_TAR)
 
-    local('git archive %s --format=tar.gz --output=%s.tar.gz %s %s %s' % (branch, TAR_NAME, CONFIG_DIR, ENV_DIR, KEY_DIR))
+
 
     # and move the tarball to the destination and expand it
     # set the upload path to the home directory
